@@ -39,12 +39,14 @@ CFLAGS="${BUILD_CFLAGS}" /usr/bin/cmake \
     -DNETDATA_USER="${USER}" \
     -DENABLE_ACLK=On \
     -DENABLE_CLOUD=On \
-    -DENABLE_H2O=Off \
     -DENABLE_ML=On \
     -DENABLE_PLUGIN_GO=On \
     -DENABLE_EXPORTER_PROMETHEUS_REMOTE_WRITE=Off \
+    -DENABLE_PLUGIN_OTEL=Off \
+    -DENABLE_PLUGIN_SYSTEMD_JOURNAL=Off \
     -DENABLE_BUNDLED_JSONC=On \
     -DENABLE_BUNDLED_PROTOBUF=Off \
+    -DRust_COMPILER=/ucrt64/bin/rustc \
     ${EXTRA_CMAKE_OPTIONS:-}
 ${GITHUB_ACTIONS+echo "::endgroup::"}
 
