@@ -15,7 +15,11 @@
 #define MEGA_FACTOR (1048576)
 #endif
 
-void *win_plugin_main(void *ptr);
+#ifndef GIGA_FACTOR
+#define GIGA_FACTOR (1073741824)
+#endif
+
+void win_plugin_main(void *ptr);
 
 extern char windows_shared_buffer[8192];
 
@@ -24,6 +28,8 @@ int do_GetSystemUptime(int update_every, usec_t dt);
 int do_GetSystemRAM(int update_every, usec_t dt);
 int do_GetSystemCPU(int update_every, usec_t dt);
 int do_GetPowerSupply(int update_every, usec_t dt);
+int do_GetServicesStatus(int update_every, usec_t dt);
+int do_GetSensors(int update_every, usec_t dt);
 
 // Perflib
 int do_PerflibStorage(int update_every, usec_t dt);
@@ -40,11 +46,14 @@ int do_PerflibAD(int update_every, usec_t dt);
 int do_PerflibADCS(int update_every, usec_t dt);
 int do_PerflibADFS(int update_every, usec_t dt);
 int do_PerflibHyperV(int update_every, usec_t dt);
-int do_PerflibServices(int update_every, usec_t dt);
 int do_PerflibExchange(int update_every, usec_t dt __maybe_unused);
 int do_PerflibNUMA(int update_every, usec_t dt __maybe_unused);
 int do_PerflibASP(int update_every, usec_t dt __maybe_unused);
 
+// Cleanup
+void do_PerflibMSSQL_cleanup();
+void do_Sensors_cleanup();
+
 enum PERFLIB_PRIO {
     PRIO_WEBSITE_IIS_REQUESTS_RATE = 21000, // PRIO selected, because APPS is using 20YYY
     PRIO_WEBSITE_IIS_REQUESTS_BY_TYPE_RATE,
@@ -114,6 +123,8 @@ enum PERFLIB_PRIO {
     PRIO_MSSQL_BUFF_CHECKPOINT_PAGES,
     PRIO_MSSQL_BUFF_METHODS_PAGE_SPLIT,
     PRIO_MSSQL_BUFF_PAGE_LIFE_EXPECTANCY,
+    PRIO_MSSQL_BUFF_LAZY_WRITE,
+    PRIO_MSSQL_BUFF_PAGE_LOOKUPS,
 
     PRIO_MSSQL_MEMMGR_CONNECTION_MEMORY_BYTES,
     PRIO_MSSQL_MEMMGR_TOTAL_SERVER,
