@@ -214,7 +214,7 @@ func (j *Job) Vnode() vnodes.VirtualNode {
 func (j *Job) AutoDetection() (err error) {
 	defer func() {
 		if r := recover(); r != nil {
-			err = fmt.Errorf("panic %v", err)
+			err = fmt.Errorf("panic %v", r)
 			j.panicked = true
 			j.disableAutoDetection()
 
@@ -312,11 +312,29 @@ func (j *Job) Cleanup() {
 		return
 	}
 
-	if !j.vnodeCreated && j.vnode.GUID != "" {
-		j.sendVnodeHostInfo()
-		j.vnodeCreated = true
+	// Netdata automatically obsoletes vnode charts when no updates are sent.
+	// For virtual nodes with a stale label, we must not send anything:
+	//   - Sending a HOST line would incorrectly mark the vnode as active.
+	isVnodeWithStaleConfig := j.vnode.Labels["_node_stale_after_seconds"] != ""
+
+	if !isVnodeWithStaleConfig {
+		if !j.vnodeCreated && j.vnode.GUID != "" {
+			j.sendVnodeHostInfo()
+			j.vnodeCreated = true
+		}
+		j.api.HOST(j.vnode.GUID)
+
+		if j.charts != nil {
+			for _, chart := range *j.charts {
+				if chart.created {
+					chart.MarkRemove()
+					j.createChart(chart)
+				}
+			}
+		}
 	}
-	j.api.HOST(j.vnode.GUID)
+
+	j.api.HOST("")
 
 	if j.collectStatusChart.created {
 		j.collectStatusChart.MarkRemove()
@@ -327,15 +345,6 @@ func (j *Job) Cleanup() {
 		j.createChart(j.collectDurationChart)
 	}
 
-	if j.charts != nil {
-		for _, chart := range *j.charts {
-			if chart.created {
-				chart.MarkRemove()
-				j.createChart(chart)
-			}
-		}
-	}
-
 	if j.buf.Len() > 0 {
 		_, _ = io.Copy(j.out, j.buf)
 	}
@@ -436,21 +445,12 @@ func (j *Job) processMetrics(metrics map[string]int64, startTime time.Time, sinc
 		}
 	}
 
+	bufLenBeforeHost := j.buf.Len()
 	j.api.HOST(j.vnode.GUID)
 
-	if !j.collectStatusChart.created || createChart {
-		j.collectStatusChart.ID = fmt.Sprintf("%s_%s_data_collection_status", cleanPluginName(j.pluginName), j.FullName())
-		j.createChart(j.collectStatusChart)
-	}
-
-	if !j.collectDurationChart.created || createChart {
-		j.collectDurationChart.ID = fmt.Sprintf("%s_%s_data_collection_duration", cleanPluginName(j.pluginName), j.FullName())
-		j.createChart(j.collectDurationChart)
-	}
-
 	elapsed := int64(durationTo(time.Since(startTime), time.Millisecond))
 
-	var i, updated int
+	var i, updated, created int
 	for _, chart := range *j.charts {
 		if !chart.created || createChart {
 			typeID := fmt.Sprintf("%s.%s", j.FullName(), chart.ID)
@@ -460,6 +460,7 @@ func (j *Job) processMetrics(metrics map[string]int64, startTime time.Time, sinc
 				chart.ignore = true
 			}
 			j.createChart(chart)
+			created++
 		}
 		if chart.remove {
 			continue
@@ -475,6 +476,22 @@ func (j *Job) processMetrics(metrics map[string]int64, startTime time.Time, sinc
 	}
 	*j.charts = (*j.charts)[:i]
 
+	if updated == 0 && created == 0 && j.vnode.GUID != "" {
+		j.buf.Truncate(bufLenBeforeHost)
+	}
+
+	j.api.HOST("")
+
+	if !j.collectStatusChart.created || createChart {
+		j.collectStatusChart.ID = fmt.Sprintf("%s_%s_data_collection_status", cleanPluginName(j.pluginName), j.FullName())
+		j.createChart(j.collectStatusChart)
+	}
+
+	if !j.collectDurationChart.created || createChart {
+		j.collectDurationChart.ID = fmt.Sprintf("%s_%s_data_collection_duration", cleanPluginName(j.pluginName), j.FullName())
+		j.createChart(j.collectDurationChart)
+	}
+
 	j.updateChart(
 		j.collectStatusChart,
 		map[string]int64{"success": metrix.Bool(updated > 0), "failed": metrix.Bool(updated == 0)},
