@@ -4,7 +4,6 @@ package k8s_kubelet
 
 import (
 	"errors"
-	"os"
 
 	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/prometheus"
 	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/web"
@@ -17,14 +16,6 @@ func (c *Collector) validateConfig() error {
 	return nil
 }
 
-func (c *Collector) initAuthToken() string {
-	bs, err := os.ReadFile(c.TokenPath)
-	if err != nil {
-		c.Warningf("error on reading service account token from '%s': %v", c.TokenPath, err)
-	}
-	return string(bs)
-}
-
 func (c *Collector) initPrometheusClient() (prometheus.Prometheus, error) {
 	httpClient, err := web.NewHTTPClient(c.ClientConfig)
 	if err != nil {
