@@ -8,9 +8,8 @@ import (
 
 	"github.com/golang/mock/gomock"
 	"github.com/gosnmp/gosnmp"
-	"github.com/stretchr/testify/assert"
-
 	snmpmock "github.com/gosnmp/gosnmp/mocks"
+	"github.com/stretchr/testify/assert"
 
 	"github.com/netdata/netdata/go/plugins/logger"
 	"github.com/netdata/netdata/go/plugins/plugin/go.d/collector/snmp/ddsnmp"
@@ -799,10 +798,16 @@ func TestDeviceMetadataCollector_Collect(t *testing.T) {
 			},
 			expectedError: false,
 		},
-		"base metadata exact via Extends": {
+		"base metadata exact via sysObjectIDs": {
 			profile: &ddsnmp.Profile{
 				Definition: &ddprofiledefinition.ProfileDefinition{
-					Extends: []string{"1.3.6.1.4.1.9.1.669"},
+					Selector: ddprofiledefinition.SelectorSpec{
+						{
+							SysObjectID: ddprofiledefinition.SelectorIncludeExclude{
+								Include: []string{"1.3.6.1.4.1.9.1.669"},
+							},
+						},
+					},
 					Metadata: ddprofiledefinition.MetadataConfig{
 						"device": {
 							Fields: ddprofiledefinition.ListMap[ddprofiledefinition.MetadataField]{
@@ -823,10 +828,16 @@ func TestDeviceMetadataCollector_Collect(t *testing.T) {
 			},
 			expectedError: false,
 		},
-		"extends exact + sysobjectid wildcard → base wins overlap": {
+		"sysObjectIDs exact + sysobjectid wildcard → base wins overlap": {
 			profile: &ddsnmp.Profile{
 				Definition: &ddprofiledefinition.ProfileDefinition{
-					Extends: []string{"1.3.6.1.4.1.9.1.669"},
+					Selector: ddprofiledefinition.SelectorSpec{
+						{
+							SysObjectID: ddprofiledefinition.SelectorIncludeExclude{
+								Include: []string{"1.3.6.1.4.1.9.1.669"},
+							},
+						},
+					},
 					Metadata: ddprofiledefinition.MetadataConfig{
 						"device": {
 							Fields: ddprofiledefinition.ListMap[ddprofiledefinition.MetadataField]{
@@ -858,7 +869,7 @@ func TestDeviceMetadataCollector_Collect(t *testing.T) {
 			},
 			expectedError: false,
 		},
-		"no extends (non-exact) + sysobjectid wildcard → wildcard wins": {
+		"non-exact + sysobjectid wildcard → wildcard wins": {
 			profile: &ddsnmp.Profile{
 				Definition: &ddprofiledefinition.ProfileDefinition{
 					Metadata: ddprofiledefinition.MetadataConfig{
@@ -891,40 +902,6 @@ func TestDeviceMetadataCollector_Collect(t *testing.T) {
 			},
 			expectedError: false,
 		},
-		"extends exact + sysobjectid exact → sysobjectid wins overlap": {
-			profile: &ddsnmp.Profile{
-				Definition: &ddprofiledefinition.ProfileDefinition{
-					Extends: []string{"1.3.6.1.4.1.9.1.669"},
-					Metadata: ddprofiledefinition.MetadataConfig{
-						"device": {
-							Fields: ddprofiledefinition.ListMap[ddprofiledefinition.MetadataField]{
-								"vendor": {Value: "Cisco-Base"},
-								"model":  {Value: "BaseModel"},
-							},
-						},
-					},
-					SysobjectIDMetadata: []ddprofiledefinition.SysobjectIDMetadataEntryConfig{
-						{
-							SysobjectID: "1.3.6.1.4.1.9.1.669", // exact
-							Metadata: ddprofiledefinition.ListMap[ddprofiledefinition.MetadataField]{
-								"vendor": {Value: "Cisco-Exact"},
-								"model":  {Value: "ASA5510"},
-								"series": {Value: "ASA5500"},
-							},
-						},
-					},
-				},
-			},
-			setupMock:   func(m *snmpmock.MockHandler) {},
-			sysobjectid: "1.3.6.1.4.1.9.1.669",
-			expectedResult: map[string]ddsnmp.MetaTag{
-				// sysobjectid exact (written first) holds; base exact does not overwrite exact
-				"vendor": {Value: "Cisco-Exact", IsExactMatch: true},
-				"model":  {Value: "ASA5510", IsExactMatch: true},
-				"series": {Value: "ASA5500", IsExactMatch: true},
-			},
-			expectedError: false,
-		},
 	}
 
 	for name, tc := range tests {
