@@ -3,10 +3,8 @@
 package ddsnmp
 
 import (
-	"errors"
 	"fmt"
 	"path/filepath"
-	"regexp"
 	"slices"
 	"sort"
 	"strings"
@@ -14,45 +12,52 @@ import (
 	"github.com/netdata/netdata/go/plugins/plugin/go.d/collector/snmp/ddsnmp/ddprofiledefinition"
 )
 
-var oidOnly = regexp.MustCompile(`^[0-9]+(\.[0-9]+)*$`)
-
-func OidMatches(sysObjId, id string) bool {
-	if oidOnly.MatchString(id) {
-		return sysObjId == id
-	}
-	re, err := regexp.Compile(id)
-	if err != nil {
-		log.Warningf("invalid regex %q: %v", id, err)
-		return false
-	}
-	return re.MatchString(sysObjId)
-}
-
 // FindProfiles returns profiles matching the given sysObjectID.
 // Profiles are sorted by match specificity: most specific first.
-func FindProfiles(sysObjId string) []*Profile {
+func FindProfiles(sysObjID, sysDescr string, manualProfiles []string) []*Profile {
 	loadProfiles()
 
+	finalize := func(profiles []*Profile) []*Profile {
+		if len(profiles) == 0 {
+			return nil
+		}
+		enrichProfiles(profiles)
+		deduplicateMetricsAcrossProfiles(profiles)
+		return profiles
+	}
+
+	// Fallback/manual path (no sysObjectID)
+	if sysObjID == "" {
+		if len(manualProfiles) == 0 {
+			log.Warning("No sysObjectID found and no manual_profiles configured. Either ensure the device provides sysObjectID or configure manual_profiles option.")
+			return nil
+		}
+
+		var selected []*Profile
+		for _, prof := range ddProfiles {
+			name := stripFileNameExt(prof.SourceFile)
+			if slices.ContainsFunc(manualProfiles, func(p string) bool { return stripFileNameExt(p) == name }) {
+				selected = append(selected, prof.clone())
+			}
+		}
+
+		return finalize(selected)
+	}
+
+	// Auto-detect path
 	matchedOIDs := make(map[*Profile]string)
-	var profiles []*Profile
+	var selected []*Profile
 
 	for _, prof := range ddProfiles {
-		// Use first matching OID (profile author's responsibility to order them)
-		for _, id := range prof.Definition.SysObjectIDs {
-			if OidMatches(sysObjId, id) {
-				cloned := prof.clone()
-				profiles = append(profiles, cloned)
-				matchedOIDs[cloned] = id
-				break
-			}
+		if ok, matchedOid := prof.Definition.Selector.Matches(sysObjID, sysDescr); ok {
+			cloned := prof.clone()
+			selected = append(selected, cloned)
+			matchedOIDs[cloned] = matchedOid
 		}
 	}
 
-	sortProfilesBySpecificity(profiles, matchedOIDs)
-
-	enrichProfiles(profiles)
-	deduplicateMetricsAcrossProfiles(profiles)
-	return profiles
+	sortProfilesBySpecificity(selected, matchedOIDs)
+	return finalize(selected)
 }
 
 type (
@@ -223,27 +228,7 @@ func (p *Profile) mergeMetadata(base *Profile) {
 }
 
 func (p *Profile) validate() error {
-	ddprofiledefinition.NormalizeMetrics(p.Definition.Metrics)
-
-	var errs []error
-
-	for _, err := range ddprofiledefinition.ValidateEnrichMetadata(p.Definition.Metadata) {
-		errs = append(errs, errors.New(err))
-	}
-	for _, err := range ddprofiledefinition.ValidateEnrichSysobjectIDMetadata(p.Definition.SysobjectIDMetadata) {
-		errs = append(errs, errors.New(err))
-	}
-	for _, err := range ddprofiledefinition.ValidateEnrichMetrics(p.Definition.Metrics) {
-		errs = append(errs, errors.New(err))
-	}
-	for _, err := range ddprofiledefinition.ValidateEnrichMetricTags(p.Definition.MetricTags) {
-		errs = append(errs, errors.New(err))
-	}
-	if len(errs) > 0 {
-		return errors.Join(errs...)
-	}
-
-	return nil
+	return ddprofiledefinition.ValidateEnrichProfile(p.Definition)
 }
 
 func (p *Profile) removeConstantMetrics() {
@@ -274,14 +259,29 @@ func sortProfilesBySpecificity(profiles []*Profile, matchedOIDs map[*Profile]str
 		aOID := matchedOIDs[a]
 		bOID := matchedOIDs[b]
 
-		// 1. Longer OIDs first (more specific)
+		// 0) Profiles with an OID match (non-empty) come before descr-only matches (empty)
+		aHasOID := aOID != ""
+		bHasOID := bOID != ""
+		if aHasOID != bHasOID {
+			if aHasOID {
+				return -1
+			}
+			return 1
+		}
+
+		// If both are descr-only (both empty), keep stable order.
+		if !aHasOID && !bHasOID {
+			return 0
+		}
+
+		// 1) Longer OIDs first (more specific)
 		if diff := len(bOID) - len(aOID); diff != 0 {
 			return diff
 		}
 
-		// 2. Same length: exact OIDs before patterns
-		aIsExact := oidOnly.MatchString(aOID)
-		bIsExact := oidOnly.MatchString(bOID)
+		// 2) Same length: exact OIDs before patterns
+		aIsExact := ddprofiledefinition.IsPlainOid(aOID)
+		bIsExact := ddprofiledefinition.IsPlainOid(bOID)
 		if aIsExact != bIsExact {
 			if aIsExact {
 				return -1
@@ -289,7 +289,7 @@ func sortProfilesBySpecificity(profiles []*Profile, matchedOIDs map[*Profile]str
 			return 1
 		}
 
-		// 3. Same type: lexicographic order for stability
+		// 3) Same type: lexicographic order for stability
 		return strings.Compare(aOID, bOID)
 	})
 }
